@@ -152,7 +152,7 @@ module TZInfo
       end
       country 'BV', 'Bouvet Island'
       country 'BW', 'Botswana' do |c|
-        c.timezone 'Africa/Gaborone', -103, 4, 311, 12
+        c.timezone 'Africa/Gaborone', -493, 20, 311, 12
       end
       country 'BY', 'Belarus' do |c|
         c.timezone 'Europe/Minsk', 539, 10, 827, 30
@@ -173,7 +173,7 @@ module TZInfo
         c.timezone 'America/Thunder_Bay', 2903, 60, -357, 4, 'Eastern Time - Thunder Bay, Ontario'
         c.timezone 'America/Iqaluit', 956, 15, -1027, 15, 'Eastern Time - east Nunavut - most locations'
         c.timezone 'America/Pangnirtung', 992, 15, -986, 15, 'Eastern Time - Pangnirtung, Nunavut'
-        c.timezone 'America/Resolute', 33613, 450, -22759, 240, 'Eastern Time - Resolute, Nunavut'
+        c.timezone 'America/Resolute', 33613, 450, -22759, 240, 'Eastern Standard Time - Resolute, Nunavut'
         c.timezone 'America/Atikokan', 175531, 3600, -54973, 600, 'Eastern Standard Time - Atikokan, Ontario and Southampton I, Nunavut'
         c.timezone 'America/Rankin_Inlet', 3769, 60, -331499, 3600, 'Central Time - central Nunavut'
         c.timezone 'America/Winnipeg', 2993, 60, -1943, 20, 'Central Time - Manitoba & west Ontario'
@@ -585,7 +585,7 @@ module TZInfo
         c.timezone 'Africa/Windhoek', -677, 30, 171, 10
       end
       country 'NC', 'New Caledonia' do |c|
-        c.timezone 'Pacific/Noumea', -334, 15, 331, 2
+        c.timezone 'Pacific/Noumea', -334, 15, 3329, 20
       end
       country 'NE', 'Niger' do |c|
         c.timezone 'Africa/Niamey', 811, 60, 127, 60
@@ -606,7 +606,7 @@ module TZInfo
         c.timezone 'Europe/Oslo', 719, 12, 43, 4
       end
       country 'NP', 'Nepal' do |c|
-        c.timezone 'Asia/Katmandu', 1663, 60, 5119, 60
+        c.timezone 'Asia/Kathmandu', 1663, 60, 5119, 60
       end
       country 'NR', 'Nauru' do |c|
         c.timezone 'Pacific/Nauru', -31, 60, 2003, 12
@@ -687,6 +687,7 @@ module TZInfo
         c.timezone 'Asia/Yekaterinburg', 1137, 20, 303, 5, 'Moscow+02 - Urals'
         c.timezone 'Asia/Omsk', 55, 1, 367, 5, 'Moscow+03 - west Siberia'
         c.timezone 'Asia/Novosibirsk', 1651, 30, 995, 12, 'Moscow+03 - Novosibirsk'
+        c.timezone 'Asia/Novokuznetsk', 215, 4, 5227, 60, 'Moscow+03 - Novokuznetsk'
         c.timezone 'Asia/Krasnoyarsk', 3361, 60, 557, 6, 'Moscow+04 - Yenisei River'
         c.timezone 'Asia/Irkutsk', 784, 15, 313, 3, 'Moscow+05 - Lake Baikal'
         c.timezone 'Asia/Yakutsk', 62, 1, 389, 3, 'Moscow+06 - Lena River'
@@ -787,7 +788,7 @@ module TZInfo
         c.timezone 'Africa/Tunis', 184, 5, 611, 60
       end
       country 'TO', 'Tonga' do |c|
-        c.timezone 'Pacific/Tongatapu', -127, 6, 1051, 6
+        c.timezone 'Pacific/Tongatapu', -127, 6, -1051, 6
       end
       country 'TR', 'Turkey' do |c|
         c.timezone 'Europe/Istanbul', 2461, 60, 869, 30
@@ -855,7 +856,7 @@ module TZInfo
         c.timezone 'Asia/Tashkent', 124, 3, 693, 10, 'east Uzbekistan'
       end
       country 'VA', 'Vatican City' do |c|
-        c.timezone 'Europe/Vatican', 419, 10, 249, 20
+        c.timezone 'Europe/Vatican', 9428, 225, 44831, 3600
       end
       country 'VC', 'St Vincent' do |c|
         c.timezone 'America/St_Vincent', 263, 20, -1837, 30
